SQL Functions
=============

Red Bird's SQL functions are functional tools
to perform simple SQL operations. They provide
functional alternative to :py:class:`redbird.sql.Table`.
They simply create an instance of the class and
call its methods.

Basic Operations
----------------

.. autofunction:: redbird.sql.select

.. autofunction:: redbird.sql.insert

.. autofunction:: redbird.sql.update

.. autofunction:: redbird.sql.delete

Additional Functions
--------------------

.. autofunction:: redbird.sql.execute

.. autofunction:: redbird.sql.create_table

.. autofunction:: redbird.sql.count

